/*-
# X-BASED RUBIK'S CUBE(tm)
#
#  Rubik3d.h
#
###
#
#  Copyright (c) 1994 - 2002	David Albert Bagley, bagleyd@tux.org
#
#                   All Rights Reserved
#
#  Permission to use, copy, modify, and distribute this software and
#  its documentation for any purpose and without fee is hereby granted,
#  provided that the above copyright notice appear in all copies and
#  that both that copyright notice and this permission notice appear in
#  supporting documentation, and that the name of the author not be
#  used in advertising or publicity pertaining to distribution of the
#  software without specific, written prior permission.
#
#  This program is distributed in the hope that it will be "playable",
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
*/

/* Public header file for Rubik3d */

#ifndef _XtRubik3d_h
#define _XtRubik3d_h

/***********************************************************************
 *
 * Rubik3d Widget
 *
 ***********************************************************************/

#include "Rubik.h"

typedef struct _Rubik3DRec *Rubik3DWidget;
#ifndef WINVER
typedef struct _Rubik3DClassRec *Rubik3DWidgetClass;
extern WidgetClass rubik3dWidgetClass;
#endif

#endif /* _XtRubik3d_h */
/* DON'T ADD STUFF AFTER THIS #endif */
